<?php
Header("Content-type: text/plain; charset=utf-8");

$filename  = "soubor.xml";     // jméno zpracovávaného souboru

// vytvoření parseru
$parser = xml_parser_create_ns();

// nastavení parametrů
xml_parser_set_option($parser, XML_OPTION_CASE_FOLDING, false);

// nastavení funkcí pro obsluhu událostí
xml_set_element_handler($parser, "startElement", "endElement");
xml_set_character_data_handler($parser, "characters");
xml_set_default_handler($parser, "defaultHandler");
xml_set_external_entity_ref_handler($parser, "entityHandler");
xml_set_processing_instruction_handler($parser, "PIHandler");
xml_set_start_namespace_decl_handler($parser, "startNamespace");
xml_set_end_namespace_decl_handler($parser, "endNamespace");

// otevření dokumentu XML
$fp = fopen($filename, "r");
if (!$fp) die ("Nelze otevřít soubor: $filename.");

// zpracování celého souboru
while ($data = fread($fp, 4096))
{
  if (!xml_parse($parser, $data, feof($fp)))
    die (sprintf("\nChyba při čtení XML: '%s' na řádce %d sloupec %d (offset %d).\n",
                 xml_error_string(xml_get_error_code($parser)),
                 xml_get_current_line_number($parser),
                 xml_get_current_column_number($parser),
                 xml_get_current_byte_index($parser)));
}

// uvolnění paměti alokované parserem
xml_parser_free($parser);

// funkce pro jednoduchou obsluhu událostí

// obsluha začátku elementu
function startElement($parser, $name, $attrs)
{
  echo "Událost začátek elementu: $name\n";
}

// zpracování konce elementu
function endElement($parser, $name)
{
  echo "Událost konec elementu: $name\n";
}

// obsluha znakových dat
function characters($parser, $data)
{
  echo "Událost znaková data: $data\n";
}

// obsluha ostatních druhů dat
function defaultHandler($parser, $data)
{
  echo "Událost ostatní data: $data\n";
}

// obsluha externích entit
function entityHandler($parser, $openEntityNames, $base, $systemId, $publicId)
{
  echo "Událost externí entita: $systemId ($publicId)\n";
}

// obsluha instrukcí pro zpracování
function PIHandler($parser, $target, $data)
{
  echo "Událost instrukce pro zpracování: $target ($data)\n";
}

// obsluha začátku platnosti prefixu jmenného prostoru
function startNamespace($parser, $prefix, $uri)
{
  echo "Událost začátek platnosti prefixu NS: $prefix ($uri)\n";
}

// obsluha konce platnosti prefixu jmenného prostoru
function endNamespace($parser, $prefix)
{
  echo "Událost konec platnosti prefixu NS: $prefix\n";
}

?>